@@ -15,7 +15,7 @@ __all__ = [
     'tasks',
     'utils',
     'exceptions',
-    'PlatformJourneyTask'
+    'SwitchGuideTask'
 ]
 
 from . import models
@@ -23,6 +23,6 @@ from . import exceptions
 from . import tasks
 from . import exceptions
 from . import utils
-from .PlatformJourneyTask import PlatformJourneyTask
+from .SwitchGuideTask import SwitchGuideTask
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
